===========
Long labels
===========

Long labels do not sit well in figures. If overlayed on the plot they obscure
most of the figure. Long labels on the axes will either be truncated
or rescale the plot area such that little space is left for the actual
plot. The font-size of labels can be reduced at the expense of
legibility.



